# S390x support

To build the calico images for s390x follow the instructions from the
[linux on IBM-z repository](https://github.com/linux-on-ibm-z/docs/wiki/Building-Calico-3.x).

In what follows we focus on v3.15.1.

## Dependencies

Get docker with:
```
apt-get docker.io
```

## Build the images

Calico main images:
```
wget https://raw.githubusercontent.com/linux-on-ibm-z/scripts/master/Calico/3.15.1/build_calico.sh
chmod +x ./build_calico.sh
./build_calico.sh
```

For pod2daemon and k8s-policy go is needed but is installed by the `build_calico.sh`.
```
export GOPATH="$HOME/go/"

git clone -b v3.15.1 https://github.com/projectcalico/pod2daemon.git $GOPATH/src/github.com/projectcalico/pod2daemon
cd $HOME/go/src/github.com/projectcalico/pod2daemon
ARCH=s390x make GO_BUILD_VER=v0.40 image

git clone -b v3.15.1 https://github.com/projectcalico/k8s-policy.git $GOPATH/src/github.com/projectcalico/k8s-policy
cd $GOPATH/src/github.com/projectcalico/k8s-policy
ARCH=s390x make image
```

## Tag and release images

After logging in with `docker login`:

```
docker tag calico/node:latest-s390x cdkbot/calico-node-s390x:v3.15.1
docker tag calico/felix:latest-s390x cdkbot/calico-felix-s390x:v3.15.1
docker tag calico/typha:latest-s390x cdkbot/calico-typha-s390x:v3.15.1
docker tag calico/ctl:latest-s390x cdkbot/calico-ctl-s390x:v3.15.1
docker tag calico/cni:latest-s390x cdkbot/calico-cni-s390x:v3.15.1
docker tag calico/pod2daemon-flexvol:latest-s390x cdkbot/calico-pod2daemon-flexvol-s390x:v3.15.1
docker tag calico/kube-controllers:latest-s390x cdkbot/calico-kube-controllers-s390x:v3.15.1
docker tag calico/flannel-migration-controller:latest-s390x cdkbot/calico-flannel-migration-controller-s390x:v3.15.1

docker push cdkbot/calico-node-s390x:v3.15.1
docker push cdkbot/calico-felix-s390x:v3.15.1
docker push cdkbot/calico-typha-s390x:v3.15.1
docker push cdkbot/calico-ctl-s390x:v3.15.1
docker push cdkbot/calico-cni-s390x:v3.15.1
docker push cdkbot/calico-pod2daemon-flexvol-s390x:v3.15.1
docker push cdkbot/calico-kube-controllers-s390x:v3.15.1
docker push cdkbot/calico-flannel-migration-controller-s390x:v3.15.1
```

## Prepare the cni manifest

Select the calico manifest that matches the version of calico you build. Calico releases are on
[github](https://github.com/projectcalico/calico/releases).
In the case of v3.15 we need to follow the instructions from the [official docs](https://docs.projectcalico.org/archive/v3.15/getting-started/kubernetes/self-managed-onprem/onpremises#install-calico-with-kubernetes-api-datastore-50-nodes-or-less).

As a final step update the calico manifest according to the changes describe in the [build doc](https://github.com/ubuntu/microk8s/blob/master/docs/build.md) page.

# References
 * Build calico from linux on IBM-z: https://github.com/linux-on-ibm-z/docs/wiki/Building-Calico-3.x
 * Calico releases: https://github.com/projectcalico/calico/releases
